package com.dcsoft.system.service;

import java.util.List;
import com.dcsoft.system.domain.SysManageRecord;

/**
 * 授权管理记录Service接口
 * 
 * @author dcsoft
 * @date 2023-03-08
 */
public interface ISysManageRecordService 
{
    /**
     * 查询授权管理记录
     * 
     * @param id 授权管理记录主键
     * @return 授权管理记录
     */
    public SysManageRecord selectSysManageRecordById(Long id);

    /**
     * 查询授权管理记录列表
     * 
     * @param sysManageRecord 授权管理记录
     * @return 授权管理记录集合
     */
    public List<SysManageRecord> selectSysManageRecordList(SysManageRecord sysManageRecord);

    /**
     * 新增授权管理记录
     * 
     * @param sysManageRecord 授权管理记录
     * @return 结果
     */
    public int insertSysManageRecord(SysManageRecord sysManageRecord);

    /**
     * 修改授权管理记录
     * 
     * @param sysManageRecord 授权管理记录
     * @return 结果
     */
    public int updateSysManageRecord(SysManageRecord sysManageRecord);

    /**
     * 批量删除授权管理记录
     * 
     * @param ids 需要删除的授权管理记录主键集合
     * @return 结果
     */
    public int deleteSysManageRecordByIds(Long[] ids);

    /**
     * 删除授权管理记录信息
     * 
     * @param id 授权管理记录主键
     * @return 结果
     */
    public int deleteSysManageRecordById(Long id);
}
